<?php
/*
Plugin Name: Fancy News
Plugin URI: http://codecanyon.net/user/radykal/portfolio
Description: Add any post type to a Fancy News slider.
Version: 1.1.0
Author: radykal
Author URI: http://codecanyon.net/user/radykal
*/


if ( !defined( 'ABSPATH' ) ) { exit; } // Exit if accessed directly

if (!defined('FN_PLUGIN_DIR'))
    define( 'FN_PLUGIN_DIR', dirname(__FILE__) );


if(!class_exists('FancyNews')) {

	class FancyNews {

		private $version_field_name = 'fancynews_version';
		private $ajax_nonce;

		const CAPABILITY = "edit_fancy_news";
		const VERSION = '1.1.0';
		const DEMO = false;

		public static $add_script = false; //loads the core js files

	    public function __construct() {

			//action hooks
			add_action( 'init', array( &$this,'init' ) );
			add_action( 'admin_init', array( &$this,'init_admin' ) );
			add_action( 'wp_enqueue_scripts',array( &$this,'enqueue_styles' ) );
			add_action( 'wp_footer', array(&$this, 'enqueue_scripts') );
			add_action( 'admin_menu', array( &$this,'add_menu_pages' ) );
			add_action( 'admin_enqueue_scripts', array( &$this, 'enqueue_admin_styles_scripts') );

			add_filter( 'widget_text', 'do_shortcode' );

			add_shortcode( 'fancy_news', array( &$this, 'add_fancy_news') );

		}

		public function init() {

			//load language domain
			load_plugin_textdomain('radykal', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/');

		}

		public function init_admin() {

			//add capability to administrator
			$role = get_role( 'administrator' );
			$role->add_cap( self::CAPABILITY );

			//create ajax nonce
			$this->ajax_nonce = wp_create_nonce( 'fancy_news_ajax_nonce' );

			//ajax handlers
			add_action( 'wp_ajax_get_taxonomies', array( &$this, 'get_taxonomies' ) );
			add_action( 'wp_ajax_get_terms', array( &$this, 'get_terms' ) );

		}

		public function get_taxonomies() {

			if ( !isset($_POST['post_type']) )
			    exit;

			check_ajax_referer( 'fancy_news_ajax_nonce', '_ajax_nonce' );

			$post_type = trim($_POST['post_type']);

			//store taxonomoies names and labels in array
			$taxonomies = get_object_taxonomies( $post_type, 'objects' );
			$tax_arr = array();
			foreach($taxonomies as $taxonomy) {
				$tax_arr[$taxonomy->name] = $taxonomy->label;
			}

			echo json_encode($tax_arr);

			die;
		}

		public function get_terms() {

			if ( !isset($_POST['taxonomy']) )
			    exit;

			check_ajax_referer( 'fancy_news_ajax_nonce', '_ajax_nonce' );

			$taxonomy = trim($_POST['taxonomy']);

			//store terms names and ids in array
			$terms = get_terms( $taxonomy );
			$terms_arr = array();
			foreach($terms as $term) {
				$terms_arr[$term->name] = $term->term_id;
			}

			echo json_encode($terms_arr);

			die;
		}

		public function enqueue_styles() {

			wp_enqueue_style( 'fancy-news', plugins_url('/css/jquery.fancyNews.min.css', __FILE__), self::VERSION );
			wp_enqueue_style( 'font-awesome-4', plugins_url('/css/font-awesome.min.css', __FILE__), '4.0.3' );

		}

		public function enqueue_scripts() {

			if( self::$add_script ) {
				wp_enqueue_script( 'fancy-news', plugins_url('/js/jquery.fancyNews.min.js', __FILE__), array(
					'jquery',
					'jquery-ui-core',
					'jquery-ui-widget',
					'jquery-ui-mouse',
					'jquery-ui-draggable',
					'jquery-effects-core'),
				self::VERSION );
			}

		}


		public function add_menu_pages() {

			//add admin page to tools
			add_submenu_page( 'tools.php', __('Fancy News', 'radykal'), __('Fancy News', 'radykal'),  FancyNews::CAPABILITY, 'fancy-news-admin', array($this, 'admin_page') );

		}

		public function admin_page() {

			include_once('admin/admin-page.php');

		}

		public function enqueue_admin_styles_scripts( $hook ) {

			//enqueue css and js on admin page
			if($hook == 'tools_page_fancy-news-admin') {
				wp_enqueue_style( 'spectrum-colorpicker', plugins_url('/admin/css/spectrum.css', __FILE__), '1.0.2' );
				wp_enqueue_style( 'fancy-news-admin', plugins_url('/admin/css/admin.css', __FILE__), self::VERSION );
				wp_enqueue_script( 'spectrum-colorpicker', plugins_url('/admin/js/spectrum.js', __FILE__), false, '1.0.2' );
			}

		}


		public function add_fancy_news( $atts ) {

			extract( shortcode_atts( array(
				'post_type' => 'post',
				'taxonomy' => '',
				'terms' => '',
				'amount' => -1,
				'width' => '500px',
				'height' => 400,
				'offset' => 3,
				'excertps_per_page' => 3,
				'slide_time' => 0,
				'feed' => '',
				'background_color' => '#ECF0F1',
				'background_color_hover' => '#F3F8F9',
				'text_color' => '#333333',
				'primary_color' => '#7F8C8D',
				'linking' => 'no',
				'target_window' => '_blank',
				'infinite_loop' => 'no',
				'arrows' => 'yes',
				'vertical' => 'no',
				'center' => 'no',
				'excerpt_end' => '[....]',
				'api_key' => ''
			), $atts ) );

			self::$add_script = true;

			if(!empty($feed) && $amount == -1) {
				$amount = 100;
			}

			$selector = uniqid('fancy-news');

			if( !empty($feed) ) {

				ob_start();
				?>
					<div id="<?php echo $selector; ?>" class="fn-container"></div>
					<script type="text/javascript">

					jQuery(document).ready(function($) {
						//return;
						$('#<?php echo $selector; ?>').fancyNews({
							width: "<?php echo $width; ?>",
							height: "<?php echo $height; ?>",
							offset: <?php echo $offset; ?>,
							previewsPerPage: <?php echo $excertps_per_page; ?>,
							slideTime: <?php echo $slide_time; ?>,
							backgroundColor: "<?php echo $background_color; ?>",
							backgroundOverColor: "<?php echo $background_color_hover; ?>",
							textColor: "<?php echo $text_color; ?>",
							primaryColor: "<?php echo $primary_color; ?>",
							useLinks: <?php echo intval($linking == 'yes'); ?>,
							targetWindow: "<?php echo $target_window; ?>",
							infiniteLoop: <?php echo intval($infinite_loop == 'yes'); ?>,
							arrows: <?php echo intval($arrows == 'yes'); ?>,
							vertical: <?php echo intval($vertical == 'yes'); ?>,
							center: <?php echo intval($center == 'yes'); ?>,
							excerptEnd: "<?php echo $excerpt_end; ?>",
							feed: "<?php echo $feed; ?>",
							numOfEntries: <?php echo $amount; ?>,
							rssApiKey: "<?php echo $api_key; ?>"
						});
					});

				</script>
				<?php

				$output = ob_get_contents();
				ob_end_clean();

				return $output;

			}

			$query_args = array(
				'post_type' => $post_type,
				'posts_per_page' => $amount
			);

			if( !empty($taxonomy) && !empty($terms) ) {

				$query_args['tax_query'] = array(
					array(
						'taxonomy' => $taxonomy,
						'field' => 'id',
						'terms' => explode(',', $terms)
					)
				);

			}

			$the_query = new WP_Query( $query_args );

			//html output
			ob_start();

			if ( $the_query->have_posts() ) :
			?>
			<div id="<?php echo $selector; ?>" class="fn-container">

				<?php while ( $the_query->have_posts() ) : $the_query->the_post(); ?>
				<div title="<?php echo get_the_date(); ?>" data-link="<?php the_permalink(); ?>">
					<?php if( has_post_thumbnail() ) :
						$image = wp_get_attachment_image_src( get_post_thumbnail_id(), 'thumbnail' );
					?>
						<img src="<?php echo $image[0]; ?>" />
					<?php endif; ?>
					<div title="<?php the_title(); ?>"><?php the_content(); ?></div>
				</div>
				<?php endwhile;
				wp_reset_postdata(); ?>

			</div>
			<?php endif; ?>
			<script type="text/javascript">

				jQuery(document).ready(function($) {
					//return;
					$('#<?php echo $selector; ?>').fancyNews({
						width: "<?php echo $width; ?>",
						height: "<?php echo $height; ?>",
						offset: <?php echo $offset; ?>,
						previewsPerPage: <?php echo $excertps_per_page; ?>,
						slideTime: <?php echo $slide_time; ?>,
						backgroundColor: "<?php echo $background_color; ?>",
						backgroundOverColor: "<?php echo $background_color_hover; ?>",
						textColor: "<?php echo $text_color; ?>",
						primaryColor: "<?php echo $primary_color; ?>",
						useLinks: <?php echo intval($linking == 'yes'); ?>,
						targetWindow: "<?php echo $target_window; ?>",
						infiniteLoop: <?php echo intval($infinite_loop == 'yes'); ?>,
						arrows: <?php echo intval($arrows == 'yes'); ?>,
						vertical: <?php echo intval($vertical == 'yes'); ?>,
						center: <?php echo intval($center == 'yes'); ?>,
						excerptEnd: "<?php echo $excerpt_end; ?>",
						numOfEntries: <?php echo $amount; ?>,
					});
				});

			</script>
			<?php

			$output = ob_get_contents();
			ob_end_clean();

			return $output;
		}
	}

}

//init Fancy News
if(class_exists('FancyNews')) {

	function fancy_news_constructor() {
		$fn = new FancyNews();
	}

	add_action( 'plugins_loaded', 'fancy_news_constructor' );
}

?>